#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_NE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_NE_HPP_INCLUDED

#include <boost/simd/operator/include/functions/ne.hpp>

#endif
